@@ -1,12 +1,13 @@
+from letschatty.models.company.assets.ai_agents_v2.chatty_ai_agent_in_chat import HumanInterventionReason
 from letschatty.models.company.assets.chat_assets import ChainOfThoughtInChatTrigger
 from pydantic import BaseModel, Field, model_validator
-from typing import Dict, Any, List, Optional
+from typing import Dict, Any, List, Optional, TYPE_CHECKING
 
 from letschatty.models.base_models.ai_agent_component import AiAgentComponentType
 from letschatty.models.utils.types.identifier import StrObjectId
 from .lambda_invokation_types import InvokationType, LambdaAiEvent
 from .expected_output import ExpectedOutputIncomingMessage, ExpectedOutputSmartTag, ExpectedOutputQualityTest, IncomingMessageAIDecision
-from ...models.company.assets.ai_agents_v2.ai_agents_decision_output import IncomingMessageDecisionAction
+from ...models.company.assets.ai_agents_v2.ai_agents_decision_output import IncomingMessageDecisionAction, SmartFollowUpDecision
 
 class SmartTaggingCallbackMetadata(BaseModel):
     chat_id: StrObjectId
@@ -23,21 +24,6 @@ class InteractionCallbackMetadata(BaseModel):
     company_id: StrObjectId
     interaction_index: int
 
-class IncomingMessageCallbackMetadata(BaseModel):
-    chat_id: StrObjectId
-    company_id: StrObjectId
-    ai_agent_id: StrObjectId
-    cot_id: StrObjectId
-    trigger: str
-    # Trigger info is in: incoming_message_ids for user_message,
-    # triggered_by_user_id for manual_trigger, smart_follow_up_id for follow_up
-    triggered_by_user_id: Optional[StrObjectId] = None
-
-class IncomingMessageCallbackEvent(LambdaAiEvent):
-    type: InvokationType = InvokationType.INCOMING_MESSAGE_CALLBACK
-    data: IncomingMessageAIDecision
-    callback_metadata: IncomingMessageCallbackMetadata
-
 class QualityTestCallbackEvent(LambdaAiEvent):
     type: InvokationType = InvokationType.SINGLE_QUALITY_TEST_CALLBACK
     data: ExpectedOutputQualityTest
@@ -69,14 +55,6 @@ class ChatData(BaseModel):
     chat_id: StrObjectId
     company_id: StrObjectId
 
-class IncomingMessageEvent(LambdaAiEvent):
-    type: InvokationType = InvokationType.INCOMING_MESSAGE
-    data: ChatData
-
-class FollowUpEvent(LambdaAiEvent):
-    type: InvokationType = InvokationType.FOLLOW_UP
-    data: ChatData
-
 class QualityTestEventData(BaseModel):
     chat_example_id: StrObjectId
     company_id: StrObjectId
@@ -158,8 +136,8 @@ class SmartFollowUpDecisionOutputData(BaseModel):
     chat_id: StrObjectId
     company_id: StrObjectId
     ai_agent_id: StrObjectId
-    smart_follow_up_output: ExpectedOutputIncomingMessage
-    smart_follow_up_id: StrObjectId
+    smart_follow_up_decision: 'SmartFollowUpDecision'
+    smart_follow_up_id: Optional[StrObjectId] = None
 
 class SmartFollowUpDecisionOutputEvent(LambdaAiEvent):
     """
@@ -324,8 +302,8 @@ class EscalateAIAgentInChatEventData(BaseModel):
     """Data for escalating an AI agent (requiring human intervention)"""
     chat_id: StrObjectId
     company_id: StrObjectId
-    reason: str = Field(description="Reason for escalation (e.g., 'Complex technical issue', 'Customer request')")
-
+    reason: HumanInterventionReason = Field(description="Reason for escalation", default=HumanInterventionReason.SOMETHING_WENT_WRONG)
+    message: Optional[str] = Field(default="El agente de IA requiere de tu intervención", description="The message to display to the user if any")
 
 class EscalateAIAgentInChatEvent(LambdaAiEvent):
     """
@@ -354,3 +332,23 @@ class UnescalateAIAgentInChatEvent(LambdaAiEvent):
     """
     type: InvokationType = InvokationType.UNESCALATE_AI_AGENT_IN_CHAT
     data: UnescalateAIAgentInChatEventData
+
+
+
+class GetChainOfThoughtsByChatIdEventData(BaseModel):
+    """Data for getting chain of thoughts by chat ID"""
+    chat_id: StrObjectId
+    company_id: StrObjectId
+    skip: int = Field(default=0, description="Number of results to skip for pagination")
+    limit: int = Field(default=10, description="Number of results to return")
+
+
+class GetChainOfThoughtsByChatIdEvent(LambdaAiEvent):
+    """
+    Event to get chain of thoughts for a chat.
+
+    Returns a list of chain of thoughts associated with the given chat ID,
+    sorted by created_at (newest first), with pagination support via skip.
+    """
+    type: InvokationType = InvokationType.GET_CHAIN_OF_THOUGHTS_BY_CHAT_ID
+    data: GetChainOfThoughtsByChatIdEventData
\ No newline at end of file
