@@ -5,5 +5,5 @@ from .tag import *
 from .flow import *
 from .sale import *
 from .contact_point import *
-from .ai_agents.chatty_ai_agent import *
+from .ai_agents_v2.chatty_ai_agent import *
 from .workflow_execution import *
\ No newline at end of file
