@@ -3,9 +3,11 @@ from pydantic import Field
 from typing import Optional, Any, ClassVar
 from pydantic import BaseModel
 from ...utils.types import StrObjectId
+from datetime import datetime
+from zoneinfo import ZoneInfo
 
 class TagPreview(ChattyAssetPreview):
-    color: str
+    color: str = Field(default="#000000")
 
     @classmethod
     def get_projection(cls) -> dict[str, Any]:
