@@ -135,3 +135,31 @@ class ChattyAssetCollectionInterface(Generic[T, P], ABC):
         docs = self.collection.find(query)
         return [self.create_instance(doc) for doc in docs]
 
+    async def get_by_ids(self, ids: List[StrObjectId]) -> List[T]:
+            """
+            Get multiple assets by their IDs in a single query.
+
+            Args:
+                ids: List of asset IDs
+
+            Returns:
+                List of assets objects
+            """
+            if not ids:
+                return []
+
+            # Convert string IDs to ObjectIds
+            object_ids = [ObjectId(id) for id in ids]
+
+            # Query for all filter criteria with matching IDs
+            query = {
+                "_id": {"$in": object_ids},
+                "deleted_at": None
+            }
+
+            # Use the sync collection directly (inherited from ChattyAssetCollectionInterface)
+            docs = await self.async_collection.find(query).to_list(length=None)
+
+            # Create FilterCriteria instances
+            return [self.create_instance(doc) for doc in docs]
+
