@@ -123,8 +123,9 @@ class ChattyAssetBaseContainer(Generic[T, P], ABC):
         else:
             return list(self.items.values())
 
-    def get_all_dict_id_item(self, company_id:Optional[StrObjectId]) -> Dict[StrObjectId, T]:
-        return {item.id: item for item in self.get_all(company_id)}
+    async def get_all_dict_id_item(self, company_id:Optional[StrObjectId]) -> Dict[StrObjectId, T]:
+        items = await self.get_all(company_id)
+        return {item.id: item for item in items}
 
     def get_all_previews(self, company_id:Optional[StrObjectId]) -> List[P]:
         logger.debug(f"Getting all previews for {self.__class__.__name__}")
